Home
last modified time | relevance | path

Searched refs:device_fn (Results 1 – 9 of 9) sorted by relevance

/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Dcall-device-fn-from-host.cu11 __device__ void device_fn() {} in device_fn() function
17 __device__ ~S() { device_fn(); } in ~S()
23 __host__ __device__ void hd() { device_fn(); } in hd()
28 __host__ __device__ void hd2() { device_fn(); } in hd2()
37 device_fn(); in hd3()
41 template <typename T> __host__ __device__ void hd2() { device_fn(); } in hd2()
45 __host__ __device__ void hd() { device_fn(); } in hd()
49 template <typename T> __host__ __device__ void hd3() { device_fn(); } in hd3()
80 auto* ptr = &device_fn; in fn_ptr()
86 auto* ptr = &device_fn; // Not an error because the template isn't instantiated. in fn_ptr_template()
[all …]
H A Dtrace-through-global.cu8 __device__ void device_fn(int) {} in device_fn() function
12 device_fn(0); // expected-error {{reference to __device__ function}} in hd1()
18 device_fn(0); in hd2()
23 device_fn(0); // expected-error {{reference to __device__ function 'device_fn'}} in hd3()
29 device_fn(0); // No error; this function is never called. in hd4()
H A Dno-call-stack-for-immediate-errs.cu10 inline __device__ void device_fn(int n);
11 inline __device__ void device_fn2() { device_fn(42); } in device_fn2()
15 inline __device__ void device_fn(int n) { in device_fn() function
H A Dglobal-initializers-host.cu29 __device__ int device_fn() { return 42; } in device_fn() function
31 int n = device_fn();
H A Dimplicit-device-lambda.cu8 __device__ void device_fn() { in device_fn() function
H A Dbad-attributes.cu70 __device__ void device_fn() { in device_fn() function
H A Dcall-host-fn-from-device.cu67 __device__ void device_fn() { hd3<int>(); } in device_fn() function
/llvm-project-15.0.7/clang/test/Parser/
H A Dlambda-attr.cu4 __attribute__((device)) void device_fn() {} in device_fn() function
8 ([]() __attribute__((device)) { device_fn(); })(); in device_attr()
10 ([] __attribute__((device)) () { device_fn(); })(); in device_attr()
11 ([] __attribute__((device)) { device_fn(); })(); in device_attr()
13 ([&]() __attribute__((device)){ device_fn(); })(); in device_attr()
15 ([&] __attribute__((device)) () { device_fn(); })(); in device_attr()
16 ([&] __attribute__((device)) { device_fn(); })(); in device_attr()
18 ([&](int) __attribute__((device)){ device_fn(); })(0); in device_attr()
20 ([&] __attribute__((device)) (int) { device_fn(); })(0); in device_attr()
/llvm-project-15.0.7/llvm/docs/
H A DCompileCudaWithLLVM.rst401 __device__ void device_fn() { inline_hd2(); }